# Man greetings

> greetings  [scenario-name] - In shell mode, it prints out the greeting of a scenario. If no name are given it will print the greetings of the current scenario. If one argument is given, it will try to print out the greetings of the scenario under that scenario name.

## Usage

`greetings`

`greetings EnglishTeacher`